@@ -419,7 +419,7 @@ module Bundler
     private
 
       def relative_path
-        if path.to_s.match(%r{^#{Bundler.root.to_s}})
+        if path.to_s.match(%r{^#{Regexp.escape Bundler.root.to_s}})
           return path.relative_path_from(Bundler.root)
         end
 
@@ -472,7 +472,7 @@ module Bundler
           if result == false
             location = " at #{$1}" if hook.inspect =~ /@(.*:\d+)/
             message = "#{type} hook#{location} failed for #{installer.spec.full_name}"
-            raise Gem::InstallError, message
+            raise InstallHookError, message
           end
         end
       end
